sddl

Struct Acl

source
pub struct Acl { /* private fields */ }
The ACL structure is the header of an access control list (ACL). A complete ACL consists of an ACL structure followed by an ordered list of zero or more access control entries (ACEs).

https://learn.microsoft.com/en-us/windows/win32/api/winnt/ns-winnt-acl

Implementations

source

impl Acl

source

pub fn acl_revision(&self) -> &AclRevision

Specifies the revision level of the ACL. This value should be ACL_REVISION, unless the ACL contains an object-specific ACE, in which case this value must be ACL_REVISION_DS. All ACEs in an ACL must be at the same revision level.

source

pub fn acl_size(&self) -> &u16

Specifies the size, in bytes, of the ACL. This value includes the ACL structure, all the ACEs, and the potential unused memory.

source

pub fn ace_count(&self) -> &u16

Specifies the number of ACEs stored in the ACL.

source

pub fn ace_list(&self) -> &Vec<Ace>

source

pub fn acl_type(&self) -> &AclType

source

pub fn control_flags(&self) -> &ControlFlags

source

impl Acl

source

pub fn new( acl_revision: AclRevision, acl_type: AclType, control_flags: ControlFlags, ace_list: Vec<Ace>, ) -> Self

source

pub fn from_sddl(value: &str, domain_rid: Option<&[u32]>) -> Result<Self, Error>

parses an SDDL string

Example
use sddl::{Acl, AclType};
let acl = Acl::from_sddl("D:P(A;CIOI;GRGX;;;BU)(A;CIOI;GA;;;BA)(A;CIOI;GA;;;SY)(A;CIOI;GA;;;CO)", None).unwrap();
 
assert_eq!(*acl.acl_type(), AclType::DACL);
assert_eq!(*acl.ace_count(), 4);
source

pub fn sddl_string(&self) -> String